summaryrefslogtreecommitdiffstats
path: root/kmail/kmsearchpattern.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'kmail/kmsearchpattern.cpp')
-rw-r--r--kmail/kmsearchpattern.cpp22
1 files changed, 11 insertions, 11 deletions
diff --git a/kmail/kmsearchpattern.cpp b/kmail/kmsearchpattern.cpp
index 3d97a2b3..dc2cc4a1 100644
--- a/kmail/kmsearchpattern.cpp
+++ b/kmail/kmsearchpattern.cpp
@@ -33,7 +33,7 @@ using KMail::FilterLog;
#include <assert.h>
static const char* funcConfigNames[] =
- { "contains", "contains-not", "equals", "not-equal", "regexp",
+ { "tqcontains", "tqcontains-not", "equals", "not-equal", "regexp",
"not-regexp", "greater", "less-or-equal", "less", "greater-or-equal",
"is-in-addressbook", "is-not-in-addressbook" , "is-in-category", "is-not-in-category",
"has-attachment", "has-no-attachment"};
@@ -294,11 +294,11 @@ bool KMSearchRuleString::matches( const DwString & aStr, KMMessage & msg,
static const DwBoyerMoore to("\nTo: ");
static const DwBoyerMoore cc("\nCc: ");
static const DwBoyerMoore bcc("\nBcc: ");
// <recipients> "contains" "foo" is true if any of the fields contains
// "foo", while <recipients> "does not contain" "foo" is true if none
// of the fields contains "foo"
if ( ( function() & 1 ) == 0 ) {
- // positive function, e.g. "contains"
+ // positive function, e.g. "tqcontains"
rc = ( matches( aStr, msg, &to, 2 ) ||
matches( aStr, msg, &cc, 2 ) ||
matches( aStr, msg, &bcc, 3 ) );
@@ -357,7 +357,7 @@ bool KMSearchRuleString::matches( const KMMessage * msg ) const
msgContents = msg->headerAsString();
logContents = false;
} else if ( field() == "<recipients>" ) {
- // (mmutz 2001-11-05) hack to fix "<recipients> !contains foo" to
+ // (mmutz 2001-11-05) hack to fix "<recipients> !tqcontains foo" to
// meet user's expectations. See FAQ entry in KDE 2.2.2's KMail
// handbook
if ( function() == FuncEquals || function() == FuncNotEqual )
@@ -455,7 +455,7 @@ bool KMSearchRuleString::matchesInternal( const TQString & msgContents ) const
for( TQStringList::ConstIterator it = addressList.begin();
( it != addressList.end() );
++it ) {
- if ( !stdAb->findByEmail( KPIM::getEmailAddress( *it ) ).isEmpty() )
+ if ( !stdAb->tqfindByEmail( KPIM::getEmailAddress( *it ) ).isEmpty() )
return true;
}
return false;
@@ -468,7 +468,7 @@ bool KMSearchRuleString::matchesInternal( const TQString & msgContents ) const
for( TQStringList::ConstIterator it = addressList.begin();
( it != addressList.end() );
++it ) {
- if ( stdAb->findByEmail( KPIM::getEmailAddress( *it ) ).isEmpty() )
+ if ( stdAb->tqfindByEmail( KPIM::getEmailAddress( *it ) ).isEmpty() )
return true;
}
return false;
@@ -481,7 +481,7 @@ bool KMSearchRuleString::matchesInternal( const TQString & msgContents ) const
for( TQStringList::ConstIterator it = addressList.begin();
it != addressList.end(); ++it ) {
- KABC::Addressee::List addresses = stdAb->findByEmail( KPIM::getEmailAddress( *it ) );
+ KABC::Addressee::List addresses = stdAb->tqfindByEmail( KPIM::getEmailAddress( *it ) );
for ( KABC::Addressee::List::Iterator itAd = addresses.begin(); itAd != addresses.end(); ++itAd )
if ( (*itAd).hasCategory(category) )
@@ -498,7 +498,7 @@ bool KMSearchRuleString::matchesInternal( const TQString & msgContents ) const
for( TQStringList::ConstIterator it = addressList.begin();
it != addressList.end(); ++it ) {
- KABC::Addressee::List addresses = stdAb->findByEmail( KPIM::getEmailAddress( *it ) );
+ KABC::Addressee::List addresses = stdAb->tqfindByEmail( KPIM::getEmailAddress( *it ) );
for ( KABC::Addressee::List::Iterator itAd = addresses.begin(); itAd != addresses.end(); ++itAd )
if ( (*itAd).hasCategory(category) )
@@ -550,7 +550,7 @@ bool KMSearchRuleNumerical::matches( const KMMessage * msg ) const
} else if ( field() == "<age in days>" ) {
TQDateTime msgDateTime;
msgDateTime.setTime_t( msg->date() );
- numericalMsgContents = msgDateTime.daysTo( TQDateTime::currentDateTime() );
+ numericalMsgContents = msgDateTime.daysTo( TQDateTime::tqcurrentDateTime() );
numericalValue = contents().toInt();
msgContents.setNum( numericalMsgContents );
}
@@ -775,7 +775,7 @@ bool KMSearchPattern::matches( const DwString & aStr, bool ignoreBody ) const
}
}
-bool KMSearchPattern::matches( Q_UINT32 serNum, bool ignoreBody ) const
+bool KMSearchPattern::matches( TQ_UINT32 serNum, bool ignoreBody ) const
{
if ( isEmpty() )
return true;
@@ -294,11 +294,11 @@ bool KMSearchRuleString::matches( const DwString & aStr, KMMessage & msg,
static const DwBoyerMoore cc("\nCc: ");
static const DwBoyerMoore bcc("\nBcc: ");
- // <recipients> "contains" "foo" is true if any of the fields contains
+ // <recipients> "tqcontains" "foo" is true if any of the fields tqcontains
// "foo", while <recipients> "does not contain" "foo" is true if none
@@ -294,11 +294,11 @@ bool KMSearchRuleString::matches( const DwString & aStr, KMMessage & msg,
// "foo", while <recipients> "does not contain" "foo" is true if none
- // of the fields contains "foo"
+ // of the fields tqcontains "foo"
if ( ( function() & 1 ) == 0 ) {